library(readr)
library(car)
library(psych)
library(GPArotation)

#############################
###### STUDY 1 ##############
#############################

d_1 <- read_csv("~/Desktop/dd_study_1.csv") ##load data file
d_1 <-subset(d_1,include==1)

##descriptive stats
describe(d_1$age)
table(d_1$gender)

##reverse-coded items
d_1$DD_12<-recode(d_1$DD_12,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_1<-recode(d_1$IS_1,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_4<-recode(d_1$IS_4,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_6<-recode(d_1$IS_6,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_7<-recode(d_1$IS_7,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_10<-recode(d_1$IS_10,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_12<-recode(d_1$IS_12,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_14<-recode(d_1$IS_14,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_16<-recode(d_1$IS_16,"1=7;2=6;3=5;4=4;5=3;6=2;7=1") ##this item is excluded from all analyses 
d_1$IS_17<-recode(d_1$IS_17,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_19<-recode(d_1$IS_19,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_1$IS_22<-recode(d_1$IS_22,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")

##imputing missing value for one subject
impute_1<-c(d_1[6,]$DD_1,d_1[6,]$DD_2,d_1[6,]$DD_3,d_1[6,]$DD_4,d_1[6,]$DD_5,
            d_1[6,]$DD_6,d_1[6,]$DD_7,d_1[6,]$DD_8,d_1[6,]$DD_9,d_1[6,]$DD_10,d_1[6,]$DD_11)
mean_impute_1<-mean(impute_1)
d_1[6,]$DD_12<-mean_impute_1

##PCA with all four scales
d_pca<-d_1[c(2:47,49:54)]
matrix<-cor(d_pca, use = "complete.obs")
pc_3components<-principal(matrix, nfactors=3,rotate="varimax") ## 3 components
pc_3components
pc_2components<-principal(matrix, nfactors=2,rotate="varimax") ## 2 components
pc_2components
pc_4components<-principal(matrix, nfactors=4,rotate="varimax") ## 4 components
pc_4components

##PCA with just decision difficulty and indecisiveness
d_pca2<-d_1[c(21:47,49:54)]
matrix2<-cor(d_pca2, use = "complete.obs")
pc_DDIS<-principal(matrix2, nfactors=2,rotate="varimax") ## PCA with just decision difficulty and indecisiveness
pc_DDIS

##scoring the scales, reliabilities, intercorrelations
keys<-list(MTS = c("MTS_1","MTS_2","MTS_3","MTS_4","MTS_5","MTS_6","MTS_7"),
           AS = c("AS_1","AS_2","AS_3","AS_4","AS_5","AS_6","AS_7","AS_8","AS_9","AS_10","AS_11","AS_12"),
           DD = c("DD_1","DD_2","DD_3","DD_4","DD_5","DD_6","DD_7","DD_8","DD_9","DD_10","DD_11","DD_12"),
           IS = c("IS_1","IS_2","IS_3","IS_4","IS_5","IS_6","IS_7","IS_8","IS_9","IS_10","IS_11","IS_12",
                      "IS_13","IS_14","IS_15","IS_17","IS_18","IS_19","IS_20","IS_21","IS_22")
           )

scales<-scoreItems(keys,d_1)
scales 

#############################
###### STUDY 2 ##############
#############################

d_2 <- read_csv("~/Desktop/dd_study_2.csv") ##load data file
d_2 <-subset(d_2,include==1)

##descriptive stats
describe(d_2$age)
table(d_2$gender)

##reverse-coded items
d_2$DD_12<-recode(d_2$DD_12,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_1<-recode(d_2$IS_1,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_4<-recode(d_2$IS_4,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_6<-recode(d_2$IS_6,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_7<-recode(d_2$IS_7,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_10<-recode(d_2$IS_10,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_12<-recode(d_2$IS_12,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_14<-recode(d_2$IS_14,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_16<-recode(d_2$IS_16,"1=7;2=6;3=5;4=4;5=3;6=2;7=1") ##this item is excluded from all analyses 
d_2$IS_17<-recode(d_2$IS_17,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_19<-recode(d_2$IS_19,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$IS_22<-recode(d_2$IS_22,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$REG_5<-recode(d_2$REG_5,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$FNE_2<-recode(d_2$FNE_2,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$FNE_4<-recode(d_2$FNE_4,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$FNE_7<-recode(d_2$FNE_7,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")
d_2$FNE_10<-recode(d_2$FNE_10,"1=7;2=6;3=5;4=4;5=3;6=2;7=1")

##imputing missing value for one subject
impute_2<-c(d_2[181,]$IS_1,d_2[181,]$IS_2,d_2[181,]$IS_3,d_2[181,]$IS_4,d_2[181,]$IS_5,d_2[181,]$IS_6,d_2[181,]$IS_7,
            d_2[181,]$IS_8,d_2[181,]$IS_10,d_2[181,]$IS_11,d_2[181,]$IS_12,d_2[181,]$IS_13,d_2[181,]$IS_14,d_2[181,]$IS_15,
            d_2[181,]$IS_17,d_2[181,]$IS_18,d_2[181,]$IS_19,d_2[181,]$IS_20,d_2[181,]$IS_21,d_2[181,]$IS_22)
mean_impute_2<-mean(impute_2)
d_2[181,]$IS_9<-mean_impute_2

##scoring the scales, reliabilities, intercorrelations
keys_2<-list(MTS = c("MTS_1","MTS_2","MTS_3","MTS_4","MTS_5","MTS_6","MTS_7"),
           AS = c("AS_1","AS_2","AS_3","AS_4","AS_5","AS_6","AS_7","AS_8","AS_9","AS_10","AS_11","AS_12"),
           DD = c("DD_1","DD_2","DD_3","DD_4","DD_5","DD_6","DD_7","DD_8","DD_9","DD_10","DD_11","DD_12"),
           IS = c("IS_1","IS_2","IS_3","IS_4","IS_5","IS_6","IS_7","IS_8","IS_9","IS_10","IS_11","IS_12",
                      "IS_13","IS_14","IS_15","IS_17","IS_18","IS_19","IS_20","IS_21","IS_22"),
           MS = c("MS_1","MS_2","MS_3","MS_4","MS_5","MS_6","MS_7","MS_8","MS_9","MS_10","MS_11","MS_12",
                  "MS_13"),
           MS_HS = c("MS_11","MS_12"),
           MS_AS = c("MS_2","MS_4"),
           MS_DD = c("MS_7","MS_9"),
           Regret = c("REG_1","REG_2","REG_3","REG_4","REG_5"),
           IOU = c("IOU_1","IOU_2","IOU_3","IOU_4","IOU_5","IOU_6","IOU_7","IOU_8","IOU_9","IOU_10",
                   "IOU_11","IOU_12"),
           Dec = c("NFC_1","NFC_2","NFC_3","NFC_4","NFC_5","NFC_6"),
           FNE = c("FNE_1","FNE_2","FNE_3","FNE_4","FNE_5","FNE_6","FNE_7","FNE_8","FNE_9","FNE_10",
                   "FNE_11","FNE_12"),
           Perf = c("PE_6","PE_7","PE_8","PE_9","PE_10"),
           Ex = c("PE_1","PE_2","PE_3","PE_4","PE_5"),
           RDS = c("RAT_1","RAT_2","RAT_3","RAT_4","RAT_5")
           )

scales_2<-scoreItems(keys_2,d_2)
scales_2

##actual decision difficulty during menu choice
keys_menu<-list(DD = c("DD_1","DD_2","DD_3","DD_4","DD_5","DD_6","DD_7","DD_8","DD_9","DD_10","DD_11","DD_12"),
                IS = c("IS_1","IS_2","IS_3","IS_4","IS_5","IS_6","IS_7","IS_8","IS_9","IS_10","IS_11","IS_12",
                       "IS_13","IS_14","IS_15","IS_17","IS_18","IS_19","IS_20","IS_21","IS_22"),
                Menu1 = c("M1.DD.1","M1.DD.2"),
                Menu2 = c("M2.DD.1","M2.DD.2"),
                Menu3 = c("M3.DD.1","M3.DD.2")
                  )

menu<-scoreItems(keys_menu,d_2)
menu
